@@ -1,7 +1,6 @@
 #[cfg(test)]
 mod channnum_test;
 
-use anyhow::Result;
 use std::fmt;
 use stun::attributes::*;
 use stun::checks::*;
@@ -34,7 +33,7 @@ impl fmt::Display for ChannelNumber {
 
 impl Setter for ChannelNumber {
     // AddTo adds CHANNEL-NUMBER to message.
-    fn add_to(&self, m: &mut Message) -> Result<()> {
+    fn add_to(&self, m: &mut Message) -> Result<(), stun::Error> {
         let mut v = vec![0; CHANNEL_NUMBER_SIZE];
         v[..2].copy_from_slice(&self.0.to_be_bytes());
         // v[2:4] are zeroes (RFFU = 0)
@@ -45,7 +44,7 @@ impl Setter for ChannelNumber {
 
 impl Getter for ChannelNumber {
     // GetFrom decodes CHANNEL-NUMBER from message.
-    fn get_from(&mut self, m: &Message) -> Result<()> {
+    fn get_from(&mut self, m: &Message) -> Result<(), stun::Error> {
         let v = m.get(ATTR_CHANNEL_NUMBER)?;
 
         check_size(ATTR_CHANNEL_NUMBER, v.len(), CHANNEL_NUMBER_SIZE)?;
