@@ -1,7 +1,6 @@
 #[cfg(test)]
 mod dontfrag_test;
 
-use anyhow::Result;
 use stun::attributes::*;
 use stun::message::*;
 
@@ -11,7 +10,7 @@ pub struct DontFragmentAttr;
 
 impl Setter for DontFragmentAttr {
     // AddTo adds DONT-FRAGMENT attribute to message.
-    fn add_to(&self, m: &mut Message) -> Result<()> {
+    fn add_to(&self, m: &mut Message) -> Result<(), stun::Error> {
         m.add(ATTR_DONT_FRAGMENT, &[]);
         Ok(())
     }
@@ -19,7 +18,7 @@ impl Setter for DontFragmentAttr {
 
 impl Getter for DontFragmentAttr {
     // get_from returns true if DONT-FRAGMENT attribute is set.
-    fn get_from(&mut self, m: &Message) -> Result<()> {
+    fn get_from(&mut self, m: &Message) -> Result<(), stun::Error> {
         let _ = m.get(ATTR_DONT_FRAGMENT)?;
         Ok(())
     }
