@@ -1,7 +1,6 @@
 #[cfg(test)]
 mod lifetime_test;
 
-use anyhow::Result;
 use std::fmt;
 use std::time::Duration;
 use stun::attributes::*;
@@ -36,7 +35,7 @@ const LIFETIME_SIZE: usize = 4; // 4 bytes, 32 bits
 
 impl Setter for Lifetime {
     // AddTo adds LIFETIME to message.
-    fn add_to(&self, m: &mut Message) -> Result<()> {
+    fn add_to(&self, m: &mut Message) -> Result<(), stun::Error> {
         let mut v = vec![0; LIFETIME_SIZE];
         v.copy_from_slice(&(self.0.as_secs() as u32).to_be_bytes());
         m.add(ATTR_LIFETIME, &v);
@@ -46,7 +45,7 @@ impl Setter for Lifetime {
 
 impl Getter for Lifetime {
     // GetFrom decodes LIFETIME from message.
-    fn get_from(&mut self, m: &Message) -> Result<()> {
+    fn get_from(&mut self, m: &Message) -> Result<(), stun::Error> {
         let v = m.get(ATTR_LIFETIME)?;
 
         check_size(ATTR_LIFETIME, v.len(), LIFETIME_SIZE)?;
